# -*- coding: utf-8 -*-
from .art import *
from .art_dic import *
import sys
import doctest
import os
import zipfile

if __name__=="__main__":
    args=sys.argv
    if len(args)>1:
        if args[1].upper()=="TEST":
            doctest.testfile("test.py",optionflags=doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS, verbose=False)
        elif args[1].upper()=="LIST":
            aprint_test()
        elif args[1].upper()=="FONTS":
            font_list()
        elif len(args)>2:
            if args[1].upper()=="ALL":
                if "ARTFonts" not in os.listdir(os.getcwd()):
                    os.mkdir("ARTFonts")
                zipf = zipfile.ZipFile(os.path.join("ARTFonts", "ALL_FONT" + '.zip'), 'w', zipfile.ZIP_DEFLATED)
                print("Generating . . . ")
                for font in font_map.keys():
                    tsave(args[2], filename=os.path.join("ARTFonts", font + ".txt"), print_status=False,
                          font=font)
                    zipf.write(os.path.join("ARTFonts", font + ".txt"), font + ".txt")
                zipf.close()
                print("Done!")
                print("File -- > "+str(os.path.join("ARTFonts", "ALL_FONT" + '.zip')))
            elif args[1].upper()=="TEXT":
                if len(args)>3:
                    tprint(args[2],font=args[3])
                else:
                    tprint(args[2])
            elif args[1].upper()=="SAVE":
                if len(args)>3:
                    tsave(args[2], font=args[3])
                else:
                    tsave(args[2])
            elif args[1].upper()=="SHAPE":
                try:
                    aprint(args[2])
                except artError as e:
                    print(str(e))
                except UnicodeEncodeError:
                    print("[Warning] This art is not printable in this environment")
            else:
                help_func()
        else:
            help_func()
    else:
        help_func()






from setuptools import setup
setup(
  name = 'art',
  packages = ['art'],
  version = '0.8',
  description = 'ASCII Art Collection In Python',
  long_description='ASCII Art Collection In Python',
  author = 'Sepand Haghighi',
  author_email = 'sepand@qpage.ir',
  url = 'https://github.com/sepandhaghighi/art',
  download_url = 'https://github.com/sepandhaghighi/art/tarball/v0.8',
  keywords = "ascii art python3 python text font",
  project_urls={
        'Webpage': 'http://pycm.shaghighi.ir',
        'Source': 'https://github.com/sepandhaghighi/pycm',
    },
  install_requires=[
	  'codecov',
      ],
  python_requires='>=2.7',
  classifiers=[
      'Development Status :: 4 - Beta',
      'Intended Audience :: Developers',
      'Natural Language :: English',
      'License :: OSI Approved :: MIT License',
      'Operating System :: OS Independent',
      'Programming Language :: Python :: 2.7',
      'Programming Language :: Python :: 3.4',
      'Programming Language :: Python :: 3.5',
      'Programming Language :: Python :: 3.6',
      'Topic :: Text Processing :: Fonts',
    ],
  license='MIT',
  include_package_data=True
)
